@@ -26,9 +26,9 @@ def format_create_table(_dbstream, data):
         example_max, example_min = find_sample_value(df, name, i)
         col = dict()
         col["example"] = example_max
-        type_max = detect_type(_dbstream, name=name, example=example_max)
+        type_max = detect_type(_dbstream, name=name, example=example_max, types=data.get("types"))
         if type_max == "TIMESTAMP":
-            type_min = detect_type(_dbstream, name=name, example=example_min)
+            type_min = detect_type(_dbstream, name=name, example=example_min, types=data.get("types"))
             if type_min == type_max:
                 col["type"] = type_max
             else:
@@ -82,9 +82,9 @@ def create_columns(_dbstream, data, other_table_to_update):
     for column_name in columns_name:
         if column_name not in all_column_in_table:
             example_max, example_min = find_sample_value(df, column_name, columns_name.index(column_name))
-            type_max = detect_type(_dbstream, name=column_name, example=example_max)
+            type_max = detect_type(_dbstream, name=column_name, example=example_max, types=data.get("types"))
             if type_max == "TIMESTAMP":
-                type_min = detect_type(_dbstream, name=column_name, example=example_min)
+                type_min = detect_type(_dbstream, name=column_name, example=example_min, types=data.get("types"))
                 if type_min == type_max:
                     type_ = type_max
                 else:
